==> nextcloud-app-mail-3.2.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/is.js <==
OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "Ívafin skilaboð %s",
    "Important mail" : "Mikilvægur póstur",
    "Unread mail" : "Ólesinn póstur",
    "Important" : "Mikilvægt",
    "Work" : "Vinna",
    "Personal" : "Persónulegt",
    "Later" : "Seinna",
    "Mails" : "Póstar",
    "Mail" : "Póstur",
    "💌 A mail app for Nextcloud" : "💌 Tölvupóstforrit fyrir Nextcloud",
    "Auto" : "Sjálfvirkt",
    "Name" : "Nafn",
    "Mail address" : "Tölvupóstfang",
    "Password" : "Lykilorð",
    "Manual" : "Handvirkt",
    "IMAP Settings" : "IMAP-stillingar",
    "IMAP Host" : "IMAP-vélarheiti",
    "IMAP Security" : "IMAP-öryggi",
    "None" : "Ekkert",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP-gátt",
    "IMAP User" : "IMAP-notandi",
    "IMAP Password" : "IMAP-lykilorð",
    "SMTP Settings" : "SMTP-stillingar",
    "SMTP Host" : "SMTP-vélarheiti",
    "SMTP Security" : "SMTP-öryggi",
    "SMTP Port" : "SMTP-gátt",
    "SMTP User" : "SMTP-notandi",
    "SMTP Password" : "SMTP-lykilorð",
    "Connecting" : "Tengist",
    "Save" : "Vista",
    "Connect" : "Tengjast",
    "Password required" : "Lykilorðs er krafist",
    "Account settings" : "Stillingar notandaaðgangs",
    "Signature" : "Undirskrift",
    "A signature is added to the text of new messages and replies." : "Undirskrift verður bætt við texta nýrra skilaboða og svarpósta.",
    "Writing mode" : "Skrifhamur",
    "Preferred writing mode for new messages and replies." : "Umbeðinn skrifhamur við gerð nýrra skilaboða og svarpósta.",
    "Mail server" : "Póstþjónn",
    "Go back" : "Fara til baka",
    "Change name" : "Breyta nafni",
    "Email address" : "Tölvupóstfang",
    "Add alias" : "Bæta við samheiti",
    "Cancel" : "Hætta við",
    "Add mail account" : "Bæta við notandaaðgangi",
    "Use Gravatar and favicon avatars" : "Nota Gravatar og veftáknmyndir (favicon)",
    "Register as application for mail links" : "Skrá sem forrit fyrir pósttengla",
    "Show keyboard shortcuts" : "Birta flýtivísanir á lyklaborði",
    "From" : "Frá",
    "Select account" : "Veldu notandaaðgang",
    "To" : "Til",
    "Contact or email address …" : "Tengiliður eða tölvupóstfang …",
    "Cc" : "Afrit (Cc)",
    "Bcc" : "Falið afrit (Bcc)",
    "No contacts found." : "Engir tengiliðir fundust.",
    "Subject" : "Viðfangsefni",
    "Subject …" : "Viðfangsefni …",
    "This message came from a noreply address so your reply will probably not be read." : "Skilaboðin komu frá ekki-svara netfangi (noreply) þannig að svarið þitt verður líklega ekki lesið.",
    "The following recipients do not have a PGP key: {recipients}." : "Eftirfarandi viðtakendur eru ekki með PGP-dulritunarlykil: {recipients}.",
    "Write message …" : "Skrifa skilaboð …",
    "Saving draft …" : "Vista drög …",
    "Draft saved" : "Drög vistuð",
    "Upload attachment" : "Senda inn viðhengi",
    "Add attachment from Files" : "Bæta við viðhengi úr skrám",
    "Enable formatting" : "Virkja sniðmótun",
    "Encrypt message with Mailvelope" : "Dulrita skilaboð með Mailvelope",
    "Send" : "Senda",
    "Choose a file to add as attachment" : "Veldu skrá til að setja sem viðhengi",
    "Choose a file to share as a link" : "Veldu skrá til að deila sem tengli",
    "Confirm" : "Staðfesta",
    "No message found yet" : "Engin skilaboð hafa ennþá fundist",
    "Set up an account" : "Setja upp notandaaðgang",
    "Plain text" : "Ósniðinn texti",
    "Rich text" : "Sniðinn texti",
    "No messages" : "Engin skilaboð",
    "Draft: " : "Drög: ",
    "Unfavorite" : "Taka úr eftirlætum",
    "Favorite" : "Eftirlæti",
    "Read" : "Lesa",
    "Mark not spam" : "Merkja sem ekki-ruslpóst",
    "Mark as spam" : "Merkja sem ruslpóst",
    "Unselect" : "Afvelja",
    "Select" : "Velja",
    "Edit tags" : "Breyta merkjum",
    "More actions" : "Fleiri aðgerðir",
    "Edit as new message" : "Breyta sem nýjum skilaboðum",
    "Create event" : "Búa til atburð",
    "Blind copy recipients only" : "Einungis viðtakendur dulinna afrita",
    "No trash mailbox configured" : "Ekkert ruslpósthólf er stillt",
    "Could not delete message" : "Gat ekki eytt skilaboðum",
    "Forward" : "Áframsenda",
    "Load more" : "Hlaða inn meira",
    "Report this bug" : "Tilkynna þessa villu",
    "All day" : "Heilsdagsviðburður",
    "Create" : "Búa til",
    "Could not create event" : "Tókst ekki að útbúa atburð",
    "Comment" : "Athugasemd",
    "Accept" : "Samþykkja",
    "Decline" : "Hafna",
    "Could not open mailbox" : "Tókst ekki að opna pósthólf",
    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Geri atriðaskrá yfir skilaboðin þín. Þetta getur tekið drjúga stund fyrir stór pósthólf.",
    "Choose" : "Velja",
    "Important info" : "Mikilvægar upplýsingar",
    "Other" : "Annað",
    "Reply" : "Svara",
    "Reply to sender only" : "Svara einungis sendanda",
    "View source" : "Skoða frumkóða",
    "Message source" : "Uppruni skilaboða",
    "Import into calendar" : "Flytja inn dagatal",
    "Download attachment" : "Sækja viðhengi",
    "Save to Files" : "Vista í skrár",
    "Unnamed" : "Nafnlaust",
    "Embedded message" : "Ívafin skilaboð",
    "Choose a folder to store the attachment in" : "Veldu möppu þar sem á að geyma viðhengið",
    "Save all to Files" : "Vista allt í skrár",
    "Choose a folder to store the attachments in" : "Veldu möppu þar sem á að geyma viðhengin",
    "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "Þetta skeyti er dulritað með PGP. Settu upp Mailvelope til að afkóða það.",
    "The images have been blocked to protect your privacy." : "Lokað hefur verið á myndir til að vernda einkalíf þitt.",
    "Show images" : "Sýna myndir",
    "Message frame" : "Rammi skilaboða",
    "Quoted text" : "Tilvitnaður texti",
    "Move" : "Færa",
    "Moving" : "Færi",
    "Quota" : "Kvóti",
    "Saving" : "Vista",
    "Move up" : "Færa upp",
    "Move down" : "Færa niður",
    "Remove account" : "Remove account",
    "Loading …" : "Hleð inn …",
    "Not supported by the server" : "Ekki stutt af þjóninum",
    "{usage} of {limit} used" : "{usage} af {limit} notað",
    "Remove account {email}" : "Fjarlægja aðganginn {email}",
    "Remove {email}" : "Fjarlægja {email}",
    "Mark all as read" : "Merkja allt sem lesið",
    "Mark all messages of this mailbox as read" : "Merkja öll skilaboð í þessu pósthólfi sem lesin",
    "Edit name" : "Breyta heiti",
    "Clear cache" : "Hreinsa skyndiminni",
    "Subscribed" : "Í áskrift",
    "Sync in background" : "Samstilling í bakgrunni",
    "An error occurred, unable to rename the mailbox." : "Villa kom upp, gat ekki endurnefnt pósthólfið.",
    "_{total} message_::_{total} messages_" : ["{total} skilaboð","{total} skilaboð"],
    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} ólesið af {total}","{unread} ólesin af {total}"],
    "New message" : "Ný skilaboð",
    "Refresh" : "Endurlesa",
    "Error sending your message" : "Villa við að senda skilaboðin þín",
    "Retry" : "Reyna aftur",
    "Uploading attachments …" : "Sendi inn viðhengi…",
    "Sending …" : "Sendi ...",
    "No message selected" : "Engin skilaboð valin",
    "Message" : "Skilaboð",
    "Delete" : "Eyða",
    "Copy to clipboard" : "Afrita á klippispjald",
    "Add" : "Bæta við",
    "Close" : "Loka",
    "Tags" : "Merki",
    "Select tags" : "Veldu merki",
    "Clear" : "Hreinsa",
    "Search" : "Leita",
    "Date" : "Dagsetning",
    "Disabled" : "Óvirkt",
    "Enabled" : "Virkt",
    "Custom" : "Sérsniðið",
    "Signature …" : "Undirskrift …",
    "Save signature" : "Vista undirskrift",
    "Add tag" : "Bæta við merki",
    "Tag already exists" : "Merki er þegar til",
    "Not found" : "Fannst ekki",
    "Could not load your message thread" : "Gat ekki hlaðið inn skilaboðaþræðinum þínum",
    "Mark as unread" : "Merkja allt sem ólesið",
    "Mark as read" : "Merkja sem lesið",
    "Remove" : "Fjarlægja",
    "(organizer)" : "(skipuleggjandi)",
    "Untitled event" : "Ónefndur atburður",
    "Import into {calendar}" : "Flytja inn í {calendar}",
    "Event imported into {calendar}" : "Atburður fluttur inn í {calendar}",
    "Airplane" : "Flugvél",
    "Reservation {id}" : "Pöntun {id}",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Flug {flightNr} frá {depAirport} til {arrAirport}",
    "Train" : "Lest",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} frá {depStation} til {arrStation}",
    "Train from {depStation} to {arrStation}" : "Lest frá {depStation} til {arrStation}",
    "Mail app" : "Tölvupóstforrit",
    "The mail app allows users to read mails on their IMAP accounts." : "Tölvupóstforritið gerir notendum kleift að lesa póst á IMAP-aðgöngum sínum.",
    "Reset" : "Endurstilla",
    "Client ID" : "Biðlaraauðkenni",
    "Client secret" : "Leynilykill biðlara",
    "Email: {email}" : "Tölvupóstur: {email}",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} á {host}:{port} ({ssl} encryption)",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} á {host}:{port} ({ssl} encryption)",
    "General" : "Almennt",
    "IMAP" : "IMAP",
    "User" : "Notandi",
    "Host" : "Þjónn",
    "Port" : "Gátt",
    "SMTP" : "SMTP",
    "With the settings above, the app will create account settings in the following way:" : "Með stillingunum hér fyrir ofan, mun forritið útbúa aðgangsstillingar á eftirfarandi máta:",
    "Valid until" : "Gildir til",
    "Certificate" : "Skilríki",
    "Back" : "Til baka",
    "Submit" : "Senda inn",
    "Keyboard shortcut" : "Flýtilykill",
    "Keyboard shortcuts" : "Flýtileiðir á lyklaborði",
    "Speed up your Mail experience with these quick shortcuts." : "Flýttu fyrir vinnu þinni með póst með þessum flýtilyklum.",
    "Compose new message" : "Semja ný skilaboð",
    "Newer message" : "Nýrri skilaboð",
    "Older message" : "Eldri skilaboð",
    "Toggle star" : "Víxla stjörnumerkingu af/á",
    "Toggle unread" : "Víxla ólesnu af/á",
    "Archive" : "Setja í safnskrá",
    "Account connected" : "Aðgangur er tengdur",
    "Connect your mail account" : "Tengdu notandaaðganginn þinn",
    "Itinerary for {type} is not supported yet" : "Það er ekki ennþá stuðningur við leið af gerðinni {type}",
    "All" : "Allt",
    "Drafts" : "Drög",
    "Favorites" : "Eftirlæti",
    "Priority inbox" : "Forgangspósthólf",
    "All inboxes" : "Öll innhólf",
    "Inbox" : "Innhólf",
    "Junk" : "Ruslpóstur",
    "Sent" : "Sent",
    "Trash" : "Rusl",
    "Error while sharing file" : "Villa við deilingu skráar",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n ný skilaboð \nfrá {from}","%n ný skilaboð \nfrá {from}"],
    "Nextcloud Mail" : "Nextcloud-póstur",
    "Message sent" : "Skilaboðin hafa verið send",
    "Could not load {tag}{name}{endtag}" : "Gat ekki hlaðið inn {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Vandamál kom upp við hlaða inn {tag}{name}{endtag}",
    "Could not load your message" : "Gat ekki hlaðið inn skilaboðunum þínum",
    "Could not load the desired message" : "Gat ekki hlaðið inn umbeðnum skilaboðum",
    "Could not load the message" : "Gat ekki hlaðið inn skilaboðunum",
    "Error loading message" : "Villa við hleðslu á skilaboðum",
    "Forwarding to %s" : "Áframsendi til %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Smelltu hér ef þér er ekki beint áfram innan nokkurra sekúndna.",
    "Redirect" : "Endurbeina",
    "The link leads to %s" : "Tengillinn leiðir til %s",
    "Continue to %s" : "Halda áfram í %s"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> nextcloud-app-mail-4.1.0-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/is.js <==
OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "Ívafin skilaboð %s",
    "Important mail" : "Mikilvægur póstur",
    "No message found yet" : "Engin skilaboð hafa ennþá fundist",
    "Set up an account" : "Setja upp notandaaðgang",
    "Unread mail" : "Ólesinn póstur",
    "Important" : "Mikilvægt",
    "Work" : "Vinna",
    "Personal" : "Persónulegt",
    "Later" : "Seinna",
    "Mail" : "Póstur",
    "Mails" : "Póstar",
    "💌 A mail app for Nextcloud" : "💌 Tölvupóstforrit fyrir Nextcloud",
    "Auto" : "Sjálfvirkt",
    "Name" : "Nafn",
    "Mail address" : "Tölvupóstfang",
    "Password" : "Lykilorð",
    "Manual" : "Handvirkt",
    "IMAP Settings" : "IMAP-stillingar",
    "IMAP Host" : "IMAP-vélarheiti",
    "IMAP Security" : "IMAP-öryggi",
    "None" : "Ekkert",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP-gátt",
    "IMAP User" : "IMAP-notandi",
    "IMAP Password" : "IMAP-lykilorð",
    "SMTP Settings" : "SMTP-stillingar",
    "SMTP Host" : "SMTP-vélarheiti",
    "SMTP Security" : "SMTP-öryggi",
    "SMTP Port" : "SMTP-gátt",
    "SMTP User" : "SMTP-notandi",
    "SMTP Password" : "SMTP-lykilorð",
    "Connecting" : "Tengist",
    "Save" : "Vista",
    "Connect" : "Tengjast",
    "Password required" : "Lykilorðs er krafist",
    "Account settings" : "Stillingar notandaaðgangs",
    "Aliases" : "Samheiti",
    "Signature" : "Undirskrift",
    "A signature is added to the text of new messages and replies." : "Undirskrift verður bætt við texta nýrra skilaboða og svarpósta.",
    "Writing mode" : "Skrifhamur",
    "Preferred writing mode for new messages and replies." : "Umbeðinn skrifhamur við gerð nýrra skilaboða og svarpósta.",
    "Filters" : "Síur",
    "Mail server" : "Póstþjónn",
    "Go back" : "Fara til baka",
    "Change name" : "Breyta nafni",
    "Email address" : "Tölvupóstfang",
    "Add alias" : "Bæta við samheiti",
    "Cancel" : "Hætta við",
    "Accounts" : "Notandaaðgangar",
    "Add mail account" : "Bæta við notandaaðgangi",
    "General" : "Almennt",
    "Sorting" : "Röðun",
    "Use Gravatar and favicon avatars" : "Nota Gravatar og veftáknmyndir (favicon)",
    "Register as application for mail links" : "Skrá sem forrit fyrir pósttengla",
    "Register" : "Nýskráning",
    "Keyboard shortcuts" : "Flýtileiðir á lyklaborði",
    "Compose new message" : "Semja ný skilaboð",
    "Newer message" : "Nýrri skilaboð",
    "Older message" : "Eldri skilaboð",
    "Toggle star" : "Víxla stjörnumerkingu af/á",
    "Toggle unread" : "Víxla ólesnu af/á",
    "Archive" : "Setja í safnskrá",
    "Delete" : "Eyða",
    "Search" : "Leita",
    "Send" : "Senda",
    "Refresh" : "Endurlesa",
    "From" : "Frá",
    "Select account" : "Veldu notandaaðgang",
    "To" : "Til",
    "Contact or email address …" : "Tengiliður eða tölvupóstfang …",
    "Cc" : "Afrit (Cc)",
    "Bcc" : "Falið afrit (Bcc)",
    "Subject" : "Viðfangsefni",
    "Subject …" : "Viðfangsefni …",
    "This message came from a noreply address so your reply will probably not be read." : "Skilaboðin komu frá ekki-svara netfangi (noreply) þannig að svarið þitt verður líklega ekki lesið.",
    "The following recipients do not have a PGP key: {recipients}." : "Eftirfarandi viðtakendur eru ekki með PGP-dulritunarlykil: {recipients}.",
    "Write message …" : "Skrifa skilaboð …",
    "Saving draft …" : "Vista drög …",
    "Draft saved" : "Drög vistuð",
    "Enable formatting" : "Virkja sniðmótun",
    "Upload attachment" : "Senda inn viðhengi",
    "Add attachment from Files" : "Bæta við viðhengi úr skrám",
    "Smart picker" : "Snjall-veljari",
    "Encrypt message with Mailvelope" : "Dulrita skilaboð með Mailvelope",
    "Enter a date" : "Settu inn dagsetningu",
    "Choose a file to add as attachment" : "Veldu skrá til að setja sem viðhengi",
    "Choose a file to share as a link" : "Veldu skrá til að deila sem tengli",
    "Choose" : "Velja",
    "_{count} attachment_::_{count} attachments_" : ["{count} viðhengi","{count} viðhengi"],
    "Confirm" : "Staðfesta",
    "Plain text" : "Ósniðinn texti",
    "Rich text" : "Sniðinn texti",
    "No messages" : "Engin skilaboð",
    "Draft: " : "Drög: ",
    "Unfavorite" : "Taka úr eftirlætum",
    "Favorite" : "Eftirlæti",
    "Read" : "Lesa",
    "Mark not spam" : "Merkja sem ekki-ruslpóst",
    "Mark as spam" : "Merkja sem ruslpóst",
    "Edit tags" : "Breyta merkjum",
    "More actions" : "Fleiri aðgerðir",
    "Back" : "Til baka",
    "Edit as new message" : "Breyta sem nýjum skilaboðum",
    "Create event" : "Búa til atburð",
    "Create task" : "Búa til verkefni",
    "Blind copy recipients only" : "Einungis viðtakendur dulinna afrita",
    "No trash mailbox configured" : "Ekkert ruslpósthólf er stillt",
    "Could not delete message" : "Gat ekki eytt skilaboðum",
    "Load more" : "Hlaða inn meira",
    "Report this bug" : "Tilkynna þessa villu",
    "All day" : "Heilsdagsviðburður",
    "Description" : "Lýsing",
    "Create" : "Búa til",
    "Could not create event" : "Tókst ekki að útbúa atburð",
    "Select" : "Velja",
    "Comment" : "Athugasemd",
    "Accept" : "Samþykkja",
    "Decline" : "Hafna",
    "Remove" : "Fjarlægja",
    "email" : "tölvupóstur",
    "Itinerary for {type} is not supported yet" : "Það er ekki ennþá stuðningur við leið af gerðinni {type}",
    "Could not open mailbox" : "Tókst ekki að opna pósthólf",
    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Geri atriðaskrá yfir skilaboðin þín. Þetta getur tekið drjúga stund fyrir stór pósthólf.",
    "Important info" : "Mikilvægar upplýsingar",
    "Other" : "Annað",
    "Forward" : "Áframsenda",
    "View source" : "Skoða frumkóða",
    "Choose a folder to store the attachment in" : "Veldu möppu þar sem á að geyma viðhengið",
    "Import into calendar" : "Flytja inn dagatal",
    "Download attachment" : "Sækja viðhengi",
    "Save to Files" : "Vista í skrár",
    "Unnamed" : "Nafnlaust",
    "Embedded message" : "Ívafin skilaboð",
    "Choose a folder to store the attachments in" : "Veldu möppu þar sem á að geyma viðhengin",
    "Save all to Files" : "Vista allt í skrár",
    "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "Þetta skeyti er dulritað með PGP. Settu upp Mailvelope til að afkóða það.",
    "The images have been blocked to protect your privacy." : "Lokað hefur verið á myndir til að vernda einkalíf þitt.",
    "Show images" : "Sýna myndir",
    "Message frame" : "Rammi skilaboða",
    "Quoted text" : "Tilvitnaður texti",
    "Move" : "Færa",
    "Moving" : "Færi",
    "Quota" : "Kvóti",
    "Saving" : "Vista",
    "Move up" : "Færa upp",
    "Move down" : "Færa niður",
    "Remove account" : "Remove account",
    "Loading …" : "Hleð inn …",
    "Not supported by the server" : "Ekki stutt af þjóninum",
    "{usage} of {limit} used" : "{usage} af {limit} notað",
    "Remove {email}" : "Fjarlægja {email}",
    "Mark all as read" : "Merkja allt sem lesið",
    "Mark all messages of this mailbox as read" : "Merkja öll skilaboð í þessu pósthólfi sem lesin",
    "Rename" : "Endurnefna",
    "Clear cache" : "Hreinsa skyndiminni",
    "Subscribed" : "Í áskrift",
    "Sync in background" : "Samstilling í bakgrunni",
    "An error occurred, unable to rename the mailbox." : "Villa kom upp, gat ekki endurnefnt pósthólfið.",
    "_{total} message_::_{total} messages_" : ["{total} skilaboð","{total} skilaboð"],
    "New message" : "Ný skilaboð",
    "Error sending your message" : "Villa við að senda skilaboðin þín",
    "Retry" : "Reyna aftur",
    "Uploading attachments …" : "Sendi inn viðhengi…",
    "Sending …" : "Sendi ...",
    "Reply" : "Svara",
    "First day" : "Fyrsta dag",
    "Message" : "Skilaboð",
    "Copy to clipboard" : "Afrita á klippispjald",
    "Add" : "Bæta við",
    "Close" : "Loka",
    "Body" : "Meginmál",
    "Date" : "Dagsetning",
    "Tags" : "Merki",
    "Select tags" : "Veldu merki",
    "Last 7 days" : "Síðustu 7 daga",
    "Clear" : "Hreinsa",
    "Custom" : "Sérsniðið",
    "Signature …" : "Undirskrift …",
    "Save signature" : "Vista undirskrift",
    "Delete tag" : "Eyða merki",
    "Add tag" : "Bæta við merki",
    "Tag already exists" : "Merki er þegar til",
    "Not found" : "Fannst ekki",
    "Could not load your message thread" : "Gat ekki hlaðið inn skilaboðaþræðinum þínum",
    "Reply to sender only" : "Svara einungis sendanda",
    "Mark as unread" : "Merkja allt sem ólesið",
    "Mark as read" : "Merkja sem lesið",
    "Message source" : "Uppruni skilaboða",
    "(organizer)" : "(skipuleggjandi)",
    "Untitled event" : "Ónefndur atburður",
    "Import into {calendar}" : "Flytja inn í {calendar}",
    "Event imported into {calendar}" : "Atburður fluttur inn í {calendar}",
    "Airplane" : "Flugvél",
    "Reservation {id}" : "Pöntun {id}",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Flug {flightNr} frá {depAirport} til {arrAirport}",
    "Train" : "Lest",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} frá {depStation} til {arrStation}",
    "Train from {depStation} to {arrStation}" : "Lest frá {depStation} til {arrStation}",
    "Actions" : "Aðgerðir",
    "Priority" : "Forgangur",
    "Mail app" : "Tölvupóstforrit",
    "The mail app allows users to read mails on their IMAP accounts." : "Tölvupóstforritið gerir notendum kleift að lesa póst á IMAP-aðgöngum sínum.",
    "Reset" : "Endurstilla",
    "Client ID" : "Biðlaraauðkenni",
    "Client secret" : "Leynilykill biðlara",
    "Email: {email}" : "Tölvupóstur: {email}",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} á {host}:{port} ({ssl} encryption)",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} á {host}:{port} ({ssl} encryption)",
    "IMAP" : "IMAP",
    "User" : "Notandi",
    "Host" : "Þjónn",
    "Port" : "Gátt",
    "SMTP" : "SMTP",
    "With the settings above, the app will create account settings in the following way:" : "Með stillingunum hér fyrir ofan, mun forritið útbúa aðgangsstillingar á eftirfarandi máta:",
    "Valid until" : "Gildir til",
    "Certificate" : "Skilríki",
    "Submit" : "Senda inn",
    "Account connected" : "Aðgangur er tengdur",
    "Connect your mail account" : "Tengdu notandaaðganginn þinn",
    "Next week – {timeLocale}" : "Í næstu viku – {timeLocale}",
    "This weekend – {timeLocale}" : "Þessa helgi – {timeLocale}",
    "Tomorrow – {timeLocale}" : "Á morgun – {timeLocale}",
    "Later today – {timeLocale}" : "Síðar í dag – {timeLocale}",
    "All" : "Allt",
    "Drafts" : "Drög",
    "Favorites" : "Eftirlæti",
    "Priority inbox" : "Forgangspósthólf",
    "All inboxes" : "Öll innhólf",
    "Inbox" : "Innhólf",
    "Junk" : "Ruslpóstur",
    "Sent" : "Sent",
    "Trash" : "Rusl",
    "Error while sharing file" : "Villa við deilingu skráar",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n ný skilaboð \nfrá {from}","%n ný skilaboð \nfrá {from}"],
    "Nextcloud Mail" : "Nextcloud-póstur",
    "Message sent" : "Skilaboðin hafa verið send",
    "Could not load {tag}{name}{endtag}" : "Gat ekki hlaðið inn {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Vandamál kom upp við hlaða inn {tag}{name}{endtag}",
    "Could not load your message" : "Gat ekki hlaðið inn skilaboðunum þínum",
    "Could not load the desired message" : "Gat ekki hlaðið inn umbeðnum skilaboðum",
    "Could not load the message" : "Gat ekki hlaðið inn skilaboðunum",
    "Error loading message" : "Villa við hleðslu á skilaboðum",
    "Forwarding to %s" : "Áframsendi til %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Smelltu hér ef þér er ekki beint áfram innan nokkurra sekúndna.",
    "Redirect" : "Endurbeina",
    "The link leads to %s" : "Tengillinn leiðir til %s",
    "Continue to %s" : "Halda áfram í %s",
    "Unselect" : "Afvelja"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
